# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.13.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateWorkflowExecutionDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workflow_id': 'str',
        'run_id': 'float',
        'status': 'str',
        'queued_at': 'datetime',
        'started_at': 'datetime',
        'ended_at': 'datetime'
    }

    attribute_map = {
        'workflow_id': 'workflowId',
        'run_id': 'runId',
        'status': 'status',
        'queued_at': 'queuedAt',
        'started_at': 'startedAt',
        'ended_at': 'endedAt'
    }

    def __init__(self, workflow_id=None, run_id=None, status=None, queued_at=None, started_at=None, ended_at=None):  # noqa: E501
        """UpdateWorkflowExecutionDto - a model defined in Swagger"""  # noqa: E501
        self._workflow_id = None
        self._run_id = None
        self._status = None
        self._queued_at = None
        self._started_at = None
        self._ended_at = None
        self.discriminator = None
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if run_id is not None:
            self.run_id = run_id
        if status is not None:
            self.status = status
        if queued_at is not None:
            self.queued_at = queued_at
        if started_at is not None:
            self.started_at = started_at
        if ended_at is not None:
            self.ended_at = ended_at

    @property
    def workflow_id(self):
        """Gets the workflow_id of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The workflow_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this UpdateWorkflowExecutionDto.


        :param workflow_id: The workflow_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def run_id(self):
        """Gets the run_id of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The run_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: float
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this UpdateWorkflowExecutionDto.


        :param run_id: The run_id of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: float
        """

        self._run_id = run_id

    @property
    def status(self):
        """Gets the status of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The status of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateWorkflowExecutionDto.


        :param status: The status of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def queued_at(self):
        """Gets the queued_at of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The queued_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._queued_at

    @queued_at.setter
    def queued_at(self, queued_at):
        """Sets the queued_at of this UpdateWorkflowExecutionDto.


        :param queued_at: The queued_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: datetime
        """

        self._queued_at = queued_at

    @property
    def started_at(self):
        """Gets the started_at of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The started_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this UpdateWorkflowExecutionDto.


        :param started_at: The started_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def ended_at(self):
        """Gets the ended_at of this UpdateWorkflowExecutionDto.  # noqa: E501


        :return: The ended_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """Sets the ended_at of this UpdateWorkflowExecutionDto.


        :param ended_at: The ended_at of this UpdateWorkflowExecutionDto.  # noqa: E501
        :type: datetime
        """

        self._ended_at = ended_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateWorkflowExecutionDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateWorkflowExecutionDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
